|
From: <sv...@va...> - 2016-04-17 19:28:14
|
Author: iraisr
Date: Sun Apr 17 20:28:04 2016
New Revision: 15858
Log:
Fix compiler warnings on Solaris 12 about assigning a function pointer
of an incompatible type to signal handler.
Untyped function pointer sa_handler() is no longer available
so we leverage sa_sigaction(int, siginfo_t *, void *) instead.
n-i-bz
Modified:
trunk/memcheck/tests/amd64-solaris/context_fpu.c
trunk/memcheck/tests/amd64-solaris/context_fpu.stderr.exp
trunk/memcheck/tests/amd64-solaris/context_gpr.c
trunk/memcheck/tests/amd64-solaris/context_gpr.stderr.exp
trunk/memcheck/tests/amd64-solaris/context_rflags.c
trunk/memcheck/tests/amd64-solaris/context_rflags2.c
trunk/memcheck/tests/amd64-solaris/context_rflags2.stderr.exp
trunk/memcheck/tests/amd64-solaris/context_sse.c
trunk/memcheck/tests/amd64-solaris/context_sse.stderr.exp
trunk/memcheck/tests/solaris/context_stack_die.c
trunk/memcheck/tests/solaris/context_stack_die.stderr.exp
trunk/memcheck/tests/x86-solaris/context_eflags.c
trunk/memcheck/tests/x86-solaris/context_eflags2.c
trunk/memcheck/tests/x86-solaris/context_eflags2.stderr.exp
trunk/memcheck/tests/x86-solaris/context_fpu.c
trunk/memcheck/tests/x86-solaris/context_fpu.stderr.exp
trunk/memcheck/tests/x86-solaris/context_gpr.c
trunk/memcheck/tests/x86-solaris/context_gpr.stderr.exp
trunk/memcheck/tests/x86-solaris/context_sse.c
trunk/memcheck/tests/x86-solaris/context_sse.stderr.exp
trunk/none/tests/solaris/context_link2.c
Modified: trunk/memcheck/tests/amd64-solaris/context_fpu.c
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_fpu.c (original)
+++ trunk/memcheck/tests/amd64-solaris/context_fpu.c Sun Apr 17 20:28:04 2016
@@ -14,9 +14,10 @@
static ucontext_t uc;
static float inhandler[8];
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
int i;
+ ucontext_t *ucp = (ucontext_t *) arg;
si = *sip;
uc = *ucp;
@@ -50,7 +51,7 @@
float *px = malloc(sizeof(*px));
x0 = px[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/amd64-solaris/context_fpu.stderr.exp
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_fpu.stderr.exp (original)
+++ trunk/memcheck/tests/amd64-solaris/context_fpu.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,96 +1,96 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:96)
+ at 0x........: main (context_fpu.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:104)
+ at 0x........: main (context_fpu.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:50)
+ by 0x........: main (context_fpu.c:51)
Modified: trunk/memcheck/tests/amd64-solaris/context_gpr.c
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_gpr.c (original)
+++ trunk/memcheck/tests/amd64-solaris/context_gpr.c Sun Apr 17 20:28:04 2016
@@ -18,8 +18,10 @@
void break_out(void);
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -43,7 +45,7 @@
long *py = malloc(sizeof(*py));
y0 = py[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/amd64-solaris/context_gpr.stderr.exp
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_gpr.stderr.exp (original)
+++ trunk/memcheck/tests/amd64-solaris/context_gpr.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,18 +1,18 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:84)
+ at 0x........: main (context_gpr.c:86)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:43)
+ by 0x........: main (context_gpr.c:45)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:91)
+ at 0x........: main (context_gpr.c:93)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:43)
+ by 0x........: main (context_gpr.c:45)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:91)
+ at 0x........: main (context_gpr.c:93)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:39)
+ by 0x........: main (context_gpr.c:41)
Modified: trunk/memcheck/tests/amd64-solaris/context_rflags.c
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_rflags.c (original)
+++ trunk/memcheck/tests/amd64-solaris/context_rflags.c Sun Apr 17 20:28:04 2016
@@ -17,10 +17,10 @@
static siginfo_t si;
static ucontext_t uc;
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
si = *sip;
- uc = *ucp;
+ uc = *((ucontext_t *) arg);
}
int main(void)
@@ -29,7 +29,7 @@
pid_t pid;
long rflags;
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/amd64-solaris/context_rflags2.c
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_rflags2.c (original)
+++ trunk/memcheck/tests/amd64-solaris/context_rflags2.c Sun Apr 17 20:28:04 2016
@@ -26,8 +26,10 @@
void break_out(void);
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -45,7 +47,7 @@
int *px = malloc(sizeof(*px));
x1 = px[0] + 1;
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/amd64-solaris/context_rflags2.stderr.exp
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_rflags2.stderr.exp (original)
+++ trunk/memcheck/tests/amd64-solaris/context_rflags2.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,12 +1,12 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_rflags2.c:86)
+ at 0x........: main (context_rflags2.c:88)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_rflags2.c:45)
+ by 0x........: main (context_rflags2.c:47)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_rflags2.c:86)
+ at 0x........: main (context_rflags2.c:88)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_rflags2.c:45)
+ by 0x........: main (context_rflags2.c:47)
Modified: trunk/memcheck/tests/amd64-solaris/context_sse.c
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_sse.c (original)
+++ trunk/memcheck/tests/amd64-solaris/context_sse.c Sun Apr 17 20:28:04 2016
@@ -18,8 +18,10 @@
static upad128_t x0;
static upad128_t d0 = {0};
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -49,7 +51,7 @@
upad128_t *py = malloc(sizeof(*py));
y0 = py[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/amd64-solaris/context_sse.stderr.exp
==============================================================================
--- trunk/memcheck/tests/amd64-solaris/context_sse.stderr.exp (original)
+++ trunk/memcheck/tests/amd64-solaris/context_sse.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,96 +1,96 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:95)
+ at 0x........: main (context_sse.c:97)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:45)
+ by 0x........: main (context_sse.c:47)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:45)
+ by 0x........: main (context_sse.c:47)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:103)
+ at 0x........: main (context_sse.c:105)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:49)
+ by 0x........: main (context_sse.c:51)
Modified: trunk/memcheck/tests/solaris/context_stack_die.c
==============================================================================
--- trunk/memcheck/tests/solaris/context_stack_die.c (original)
+++ trunk/memcheck/tests/solaris/context_stack_die.c Sun Apr 17 20:28:04 2016
@@ -7,8 +7,9 @@
static volatile int *sp;
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
sp = (int *) &ucp->uc_mcontext.gregs[0];
}
@@ -20,7 +21,7 @@
volatile int zero = 0;
/* Setup a signal handler. */
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/solaris/context_stack_die.stderr.exp
==============================================================================
--- trunk/memcheck/tests/solaris/context_stack_die.stderr.exp (original)
+++ trunk/memcheck/tests/solaris/context_stack_die.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,5 +1,5 @@
Invalid read of size 4
- at 0x........: main (context_stack_die.c:38)
+ at 0x........: main (context_stack_die.c:39)
Address 0x........ is on thread 1's stack
.... bytes below stack pointer
Modified: trunk/memcheck/tests/x86-solaris/context_eflags.c
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_eflags.c (original)
+++ trunk/memcheck/tests/x86-solaris/context_eflags.c Sun Apr 17 20:28:04 2016
@@ -15,10 +15,10 @@
static siginfo_t si;
static ucontext_t uc;
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
si = *sip;
- uc = *ucp;
+ uc = *((ucontext_t *) arg);
}
int main(void)
@@ -27,7 +27,7 @@
pid_t pid;
int eflags;
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/x86-solaris/context_eflags2.c
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_eflags2.c (original)
+++ trunk/memcheck/tests/x86-solaris/context_eflags2.c Sun Apr 17 20:28:04 2016
@@ -17,8 +17,10 @@
void break_out(void);
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -36,7 +38,7 @@
int *px = malloc(sizeof(*px));
x1 = px[0] + 1;
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/x86-solaris/context_eflags2.stderr.exp
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_eflags2.stderr.exp (original)
+++ trunk/memcheck/tests/x86-solaris/context_eflags2.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,12 +1,12 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_eflags2.c:76)
+ at 0x........: main (context_eflags2.c:78)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_eflags2.c:36)
+ by 0x........: main (context_eflags2.c:38)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_eflags2.c:76)
+ at 0x........: main (context_eflags2.c:78)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_eflags2.c:36)
+ by 0x........: main (context_eflags2.c:38)
Modified: trunk/memcheck/tests/x86-solaris/context_fpu.c
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_fpu.c (original)
+++ trunk/memcheck/tests/x86-solaris/context_fpu.c Sun Apr 17 20:28:04 2016
@@ -12,9 +12,10 @@
static ucontext_t uc;
static float inhandler[8];
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
int i;
+ ucontext_t *ucp = (ucontext_t *) arg;
si = *sip;
uc = *ucp;
@@ -49,7 +50,7 @@
float *px = malloc(sizeof(*px));
x0 = px[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/x86-solaris/context_fpu.stderr.exp
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_fpu.stderr.exp (original)
+++ trunk/memcheck/tests/x86-solaris/context_fpu.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,96 +1,96 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:103)
+ at 0x........: main (context_fpu.c:104)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_fpu.c:111)
+ at 0x........: main (context_fpu.c:112)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_fpu.c:49)
+ by 0x........: main (context_fpu.c:50)
Modified: trunk/memcheck/tests/x86-solaris/context_gpr.c
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_gpr.c (original)
+++ trunk/memcheck/tests/x86-solaris/context_gpr.c Sun Apr 17 20:28:04 2016
@@ -14,8 +14,10 @@
/* x0 is always zero, but is visible to Valgrind as uninitialised. */
static int x0;
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -37,7 +39,7 @@
int *py = malloc(sizeof(*py));
y0 = py[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/x86-solaris/context_gpr.stderr.exp
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_gpr.stderr.exp (original)
+++ trunk/memcheck/tests/x86-solaris/context_gpr.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,18 +1,18 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:81)
+ at 0x........: main (context_gpr.c:83)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:37)
+ by 0x........: main (context_gpr.c:39)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:88)
+ at 0x........: main (context_gpr.c:90)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:37)
+ by 0x........: main (context_gpr.c:39)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_gpr.c:88)
+ at 0x........: main (context_gpr.c:90)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_gpr.c:33)
+ by 0x........: main (context_gpr.c:35)
Modified: trunk/memcheck/tests/x86-solaris/context_sse.c
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_sse.c (original)
+++ trunk/memcheck/tests/x86-solaris/context_sse.c Sun Apr 17 20:28:04 2016
@@ -16,8 +16,10 @@
static upad128_t x0;
static upad128_t d0 = {0};
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
+ ucontext_t *ucp = (ucontext_t *) arg;
+
si = *sip;
uc = *ucp;
@@ -47,7 +49,7 @@
upad128_t *py = malloc(sizeof(*py));
y0 = py[0];
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
Modified: trunk/memcheck/tests/x86-solaris/context_sse.stderr.exp
==============================================================================
--- trunk/memcheck/tests/x86-solaris/context_sse.stderr.exp (original)
+++ trunk/memcheck/tests/x86-solaris/context_sse.stderr.exp Sun Apr 17 20:28:04 2016
@@ -1,96 +1,96 @@
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:101)
+ at 0x........: main (context_sse.c:103)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:43)
+ by 0x........: main (context_sse.c:45)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:43)
+ by 0x........: main (context_sse.c:45)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Conditional jump or move depends on uninitialised value(s)
- at 0x........: main (context_sse.c:109)
+ at 0x........: main (context_sse.c:111)
Uninitialised value was created by a heap allocation
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (context_sse.c:47)
+ by 0x........: main (context_sse.c:49)
Modified: trunk/none/tests/solaris/context_link2.c
==============================================================================
--- trunk/none/tests/solaris/context_link2.c (original)
+++ trunk/none/tests/solaris/context_link2.c Sun Apr 17 20:28:04 2016
@@ -5,13 +5,13 @@
#include <stdio.h>
#include <ucontext.h>
-static void sighandler(int sig, siginfo_t *sip, ucontext_t *ucp)
+static void sighandler(int sig, siginfo_t *sip, void *arg)
{
ucontext_t uc2;
/* Current uc_link value has to be equal to ucp. */
getcontext(&uc2);
- assert(uc2.uc_link == ucp);
+ assert(uc2.uc_link == arg);
}
int main(void)
@@ -26,7 +26,7 @@
}
assert(!uc.uc_link);
- sa.sa_handler = sighandler;
+ sa.sa_sigaction = sighandler;
sa.sa_flags = SA_SIGINFO;
if (sigfillset(&sa.sa_mask)) {
perror("sigfillset");
@@ -5,13 +5,13 @@
{
ucontext_t uc2;
- /* Current uc_link value has to be equal to ucp. */
+ /* Current uc_link value has to be equal to (ucontext_t *) arg. */
getcontext(&uc2);
|